@@ -1,4 +1,4 @@
-# Copyright 2017,2018 IBM Corp.
+# Copyright 2017,2022 IBM Corp.
 # Copyright 2013 NEC Corporation.
 # Copyright 2011 OpenStack Foundation.
 #
@@ -14,7 +14,6 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-
 import contextlib
 import errno
 import functools
@@ -30,6 +29,7 @@ import sys
 import tempfile
 import time
 import traceback
+import string
 
 from zvmsdk import config
 from zvmsdk import constants
@@ -41,7 +41,7 @@ CONF = config.CONF
 LOG = log.LOG
 
 
-def execute(cmd):
+def execute(cmd, timeout=None):
     """ execute command, return rc and output string.
     The cmd argument can be a string or a list composed of
     the command name and each of its argument.
@@ -55,14 +55,19 @@ def execute(cmd):
     output = ""
     try:
         output = subprocess.check_output(cmd, close_fds=True,
-                                         stderr=subprocess.STDOUT)
+                                         stderr=subprocess.STDOUT,
+                                         timeout=timeout)
     except subprocess.CalledProcessError as err:
         rc = err.returncode
         output = err.output
+    except (subprocess.TimeoutExpired,
+            PermissionError) as err:
+        raise err
     except Exception as err:
         err_msg = ('Command "%s" Error: %s' % (' '.join(cmd), str(err)))
         raise exception.SDKInternalError(msg=err_msg)
 
+    output = bytes.decode(output)
     return (rc, output)
 
 
@@ -178,7 +183,7 @@ class PathUtils(object):
         return zvmsdk_image_import_repo
 
     def create_file_repository(self, file_type):
-        zvmsdk_file_repo = os.path.join(CONF.file.sdk_file_repository,
+        zvmsdk_file_repo = os.path.join(CONF.file.file_repository,
                                         file_type)
 
         if not os.path.exists(zvmsdk_file_repo):
@@ -192,7 +197,7 @@ def to_utf8(text):
     if isinstance(text, bytes):
         return text
     elif isinstance(text, six.text_type):
-        return text.encode('utf-8')
+        return text.encode()
     else:
         raise TypeError("bytes or Unicode expected, got %s"
                         % type(text).__name__)
@@ -356,7 +361,7 @@ def expect_invalid_resp_data(data=''):
         yield
     except (ValueError, TypeError, IndexError, AttributeError,
             KeyError) as err:
-        msg = ('Invalid smut response data: %s. Error: %s' %
+        msg = ('Invalid smt response data: %s. Error: %s' %
                (data, six.text_type(err)))
         LOG.error(msg)
         raise exception.SDKInternalError(msg=msg)
@@ -371,7 +376,7 @@ def wrap_invalid_resp_data_error(function):
             return function(*arg, **kwargs)
         except (ValueError, TypeError, IndexError, AttributeError,
                 KeyError) as err:
-            msg = ('Invalid smut response data. Error: %s' %
+            msg = ('Invalid smt response data. Error: %s' %
                    six.text_type(err))
             LOG.error(msg)
             raise exception.SDKInternalError(msg=msg)
@@ -407,20 +412,20 @@ def log_and_reraise_sdkbase_error(action):
 
 
 @contextlib.contextmanager
-def log_and_reraise_smut_request_failed(action=None):
+def log_and_reraise_smt_request_failed(action=None):
     """Catch SDK base exception and print error log before reraise exception.
 
     msg: the error message to be logged.
     """
     try:
         yield
-    except exception.SDKSMUTRequestFailed as err:
+    except exception.SDKSMTRequestFailed as err:
         msg = ''
         if action is not None:
             msg = "Failed to %s. " % action
-        msg += "SMUT error: %s" % err.format_message()
+        msg += "SMT error: %s" % err.format_message()
         LOG.error(msg)
-        raise exception.SDKSMUTRequestFailed(err.results, msg)
+        raise exception.SDKSMTRequestFailed(err.results, msg)
 
 
 @contextlib.contextmanager
@@ -429,28 +434,44 @@ def ignore_errors():
     try:
         yield
     except Exception as err:
-        msg = 'ignore an error:%s' % err.format_message()
-        LOG.debug(msg)
+        LOG.error('ignore an error: ' + str(err))
         pass
 
 
-def get_smut_userid():
-    """Get the userid of smut server"""
+def get_smt_userid():
+    """Get the userid of smt server"""
     cmd = ["sudo", "/sbin/vmcp", "query userid"]
     try:
         userid = subprocess.check_output(cmd,
                                          close_fds=True,
-                                         stderr=subprocess.STDOUT).split()[0]
+                                         stderr=subprocess.STDOUT)
+        userid = bytes.decode(userid)
+        userid = userid.split()[0]
         return userid
     except Exception as err:
-        msg = ("Could not find the userid of the smut server: %s") % err
+        msg = ("Could not find the userid of the smt server: %s") % err
+        raise exception.SDKInternalError(msg=msg)
+
+
+def get_lpar_name():
+    """Get the name of the LPAR that this vm is on."""
+    cmd = ["sudo", "/sbin/vmcp", "query userid"]
+    try:
+        userid = subprocess.check_output(cmd,
+                                         close_fds=True,
+                                         stderr=subprocess.STDOUT)
+        userid = bytes.decode(userid)
+        userid = userid.split()[-1]
+        return userid
+    except Exception as err:
+        msg = ("Failed to get the LPAR name for the smt server: %s") % err
         raise exception.SDKInternalError(msg=msg)
 
 
 def get_namelist():
     """Generate namelist.
 
-    Either through set CONF.zvm.namelist, or by generate based on smut userid.
+    Either through set CONF.zvm.namelist, or by generate based on smt userid.
     """
     if CONF.zvm.namelist is not None:
         # namelist length limit should be 64, but there's bug limit to 8
@@ -458,7 +479,10 @@ def get_namelist():
         if len(CONF.zvm.namelist) <= 8:
             return CONF.zvm.namelist
 
-    return ''.join(('NL', get_smut_userid().rjust(6, '0')[-6:]))
+    # return ''.join(('NL', get_smt_userid().rjust(6, '0')[-6:]))
+    # py3 compatible changes
+    userid = get_smt_userid()
+    return 'NL' + userid.rjust(6, '0')[-6:]
 
 
 def generate_iucv_authfile(fn, client):
@@ -469,11 +493,32 @@ def generate_iucv_authfile(fn, client):
         f.writelines(lines)
 
 
+def translate_response_data_to_expect_dict(results, step):
+    """
+    Translate SMT response to a python dictionary
+    ['volume name: IASFBA', 'volume_type:9336-ET', 'volume_size:564718',
+     'volume_name: IAS1CM', 'volume_type:3390-09', 'volume_size:60102']
+     translate to:
+     {'IASFBA': {'volume_type': '9336-ET', 'volume_size': '564718'},
+      'IAS1CM': {'volume_type': '3390-09', 'volume_size': '60102'}}
+    :results: the SMT response in list format
+    :step: count list members converted to one member of the directory
+    """
+    data = {}
+    for i in range(0, len(results), step):
+        volume_name = results[i].split(':')[1].strip()
+        data[volume_name] = {}
+        for k in range(1, step):
+            key, value = results[i + k].split(':')
+            data[volume_name][key] = value
+    return data
+
+
 @wrap_invalid_resp_data_error
 def translate_response_to_dict(rawdata, dirt):
-    """Translate SMUT response to a python dictionary.
+    """Translate SMT response to a python dictionary.
 
-    SMUT response example:
+    SMT response example:
     keyword1: value1\n
     keyword2: value2\n
     ...
@@ -496,7 +541,7 @@ def translate_response_to_dict(rawdata, dirt):
                 break
 
     if data == {}:
-        msg = ("Invalid smut response data. Error: No value matched with "
+        msg = ("Invalid smt response data. Error: No value matched with "
                "keywords. Raw Data: %(raw)s; Keywords: %(kws)s" %
                {'raw': rawdata, 'kws': str(dirt)})
         raise exception.SDKInternalError(msg=msg)
@@ -515,9 +560,9 @@ def make_dummy_image(image_path, d_type='CKD'):
     header = ("z/VM %(type)s Disk Image:           0 %(unit)s" %
               {'type': d_type, 'unit': d_unit})
 
-    header = bytes(' '.join((header, 'HLen: 0055', 'GZIP: 0')))
+    header = (' '.join((header, 'HLen: 0055', 'GZIP: 0')))
     with open(image_path, 'wb') as f:
-        f.write(header)
+        f.write(header.encode())
 
 
 @contextlib.contextmanager
@@ -530,10 +575,238 @@ def acquire_lock(lock):
         lock.release()
 
 
-def check_userid_exist(userid):
+def check_userid_exist(userid, needLogon=False):
+    """The successful output is: FBA0004  - DSC
+    The successful output for device is (vmcp q 0100):
+    DASD 0100 3390 IAS106 R/W      29128 CYL ON DASD  1356 SUBCHANNEL = 0003
+
+    Errors are:
+    HCPCQV003E Invalid option - XXXXX
+    HCPQVD040E Device XXXX does not exist
+    HCPCFC026E Operand missing or invalid
+    HCPCQU045E XXXXX not logged on
+
+    Success msgs:
+    HCPCQU361E LOGOFF/FORCE pending for user xxxxxx
+    """
     cmd = 'sudo vmcp q %s' % userid
     rc, output = execute(cmd)
-    if re.search('(^HCP\w\w\w003E)', output):
+    if needLogon:
+        strfail = '(^HCP\w\w\w003E|^HCP\w\w\w040E|' + \
+                    '^HCP\w\w\w026E|^HCP\w\w\w045E)'
+        strok = '(^%s)' % userid
+    else:
+        strfail = '(^HCP\w\w\w003E|^HCP\w\w\w040E|^HCP\w\w\w026E)'
+        strok = '(^%s|^HCP\w\w\w045E|^HCP\w\w\w361E)' % userid
+
+    if re.search(strfail, output):
         # userid not exist
         return False
-    return True
+    if re.search(strok, output):
+        # userid exist
+        return True
+    # When reaching here most likely the userid represents a device
+    # and anyway it's not a guest.
+    return False
+
+
+def check_userid_on_others(userid):
+    try:
+        check_userid_exist(userid)
+        cmd = 'sudo vmcp q %s' % userid
+        rc, output = execute(cmd)
+        if re.search(' - SSI', output):
+            return True
+        return False
+    except Exception as err:
+        msg = ("Could not find the userid: %s") % err
+        raise exception.SDKInternalError(msg=msg)
+
+
+def expand_fcp_list(fcp_list):
+    """Expand fcp list string into a python list object which contains
+    each fcp devices in the list string. A fcp list is composed of fcp
+    device addresses, range indicator '-', and split indicator ';'.
+
+    Example 1:
+    if fcp_list is "0011-0013;0015;0017-0018",
+    then the function will return
+    {
+      0: {'0011' ,'0012', '0013'}
+      1: {'0015'}
+      2: {'0017', '0018'}
+    }
+
+    Example 2:
+    if fcp_list is empty string: '',
+    then the function will return an empty set: {}
+
+    ATTENTION: To support multipath, we expect fcp_list should be like
+    "0011-0014;0021-0024", "0011-0014" should have been on same physical
+    WWPN which we called path0, "0021-0024" should be on another physical
+    WWPN we called path1 which is different from "0011-0014".
+    path0 and path1 should have same count of FCP devices in their group.
+    When attach, we will choose one WWPN from path0 group, and choose
+    another one from path1 group. Then we will attach this pair of WWPNs
+    together to the guest as a way to implement multipath.
+    """
+    LOG.debug("Expand FCP list %s" % fcp_list)
+
+    if not fcp_list:
+        return dict()
+    fcp_list = fcp_list.strip()
+    fcp_list = fcp_list.replace(' ', '')
+    range_pattern = '[0-9a-fA-F]{1,4}(-[0-9a-fA-F]{1,4})?'
+    match_pattern = "^(%(range)s)(;%(range)s;?)*$" % \
+                    {'range': range_pattern}
+
+    item_pattern = "(%(range)s)(,%(range)s?)*" % \
+                   {'range': range_pattern}
+
+    multi_match_pattern = "^(%(range)s)(;%(range)s;?)*$" % \
+                   {'range': item_pattern}
+
+    if not re.match(match_pattern, fcp_list) and \
+       not re.match(multi_match_pattern, fcp_list):
+        errmsg = ("Invalid FCP address %s") % fcp_list
+        raise exception.SDKInternalError(msg=errmsg)
+
+    fcp_devices = {}
+    path_no = 0
+    for _range in fcp_list.split(';'):
+        for item in _range.split(','):
+            # remove duplicate entries
+            devices = set()
+            if item != '':
+                if '-' not in item:
+                    # single device
+                    fcp_addr = int(item, 16)
+                    devices.add("%04x" % fcp_addr)
+                else:
+                    # a range of address
+                    (_min, _max) = item.split('-')
+                    _min = int(_min, 16)
+                    _max = int(_max, 16)
+                    for fcp_addr in range(_min, _max + 1):
+                        devices.add("%04x" % fcp_addr)
+                if fcp_devices.get(path_no):
+                    fcp_devices[path_no].update(devices)
+                else:
+                    fcp_devices[path_no] = devices
+        path_no = path_no + 1
+    return fcp_devices
+
+
+def shrink_fcp_list(fcp_list):
+    """ Transform a FCP list to a string.
+
+        :param fcp_list: (list) a list object contains FCPs.
+        Case 1: only one FCP in the list.
+            e.g. fcp_list = ['1A01']
+        Case 2: all the FCPs are continuous.
+            e.g. fcp_list =['1A01', '1A02', '1A03']
+        Case 3: not all the FCPs are continuous.
+            e.g. fcp_list = ['1A01', '1A02', '1A03',
+                            '1A05',
+                            '1AFF', '1B00', '1B01',
+                            '1B04']
+        Case 4: an empty list.
+            e.g. fcp_list = []
+
+        :return fcp_str: (str)
+        Case 1: fcp_str = '1A01'
+        Case 2: fcp_str = '1A01 - 1A03'
+        Case 3: fcp_str = '1A01 - 1A03, 1A05,
+                           1AFF - 1B01, 1B04'
+        Case 4: fcp_str = ''
+    """
+
+    def __transform_fcp_list_into_str(local_fcp_list):
+        """ Transform the FCP list into a string
+            by recursively do the transformation
+            against the first continuous range of the list,
+            which is being shortened by list.pop(0) on the fly
+
+            :param local_fcp_list:
+            (list) a list object contains FCPs.
+
+            In Python, hex is stored in the form of strings.
+            Because incrementing is done on integers,
+            we need to convert hex to an integer for doing math.
+        """
+        # Case 1: only one FCP in the list.
+        if len(local_fcp_list) == 1:
+            fcp_section.append(local_fcp_list[0])
+        else:
+            start_fcp = int(local_fcp_list[0], 16)
+            end_fcp = int(local_fcp_list[-1], 16)
+            count = len(local_fcp_list) - 1
+            # Case 2: all the FCPs are continuous.
+            if start_fcp + count == end_fcp:
+                # e.g. hex(int('1A01',16)) is '0x1a01'
+                section_str = '{} - {}'.format(
+                    hex(start_fcp)[2:], hex(end_fcp)[2:])
+                fcp_section.append(section_str)
+            # Case 3: not all the FCPs are continuous.
+            else:
+                start_fcp = int(local_fcp_list.pop(0), 16)
+                for idx, fcp in enumerate(local_fcp_list.copy()):
+                    next_fcp = int(fcp, 16)
+                    # pop the fcp if it is continuous with the last
+                    # e.g.
+                    # when start_fcp is '1A01',
+                    # pop '1A02' and '1A03'
+                    if start_fcp + idx + 1 == next_fcp:
+                        local_fcp_list.pop(0)
+                        continue
+                    # e.g.
+                    # when start_fcp is '1A01',
+                    # next_fcp '1A05' is NOT continuous with the last
+                    else:
+                        end_fcp = start_fcp + idx
+                        # e.g.
+                        # when start_fcp is '1A01',
+                        # end_fcp is '1A03'
+                        if start_fcp != end_fcp:
+                            # e.g. hex(int('1A01',16)) is '0x1a01'
+                            section_str = '{} - {}'.format(
+                                hex(start_fcp)[2:], hex(end_fcp)[2:])
+                        # e.g.
+                        # when start_fcp is '1A05',
+                        # end_fcp is '1A05'
+                        else:
+                            section_str = hex(start_fcp)[2:]
+                        fcp_section.append(section_str)
+                        break
+                # recursively transform if FCP list still not empty
+                if local_fcp_list:
+                    __transform_fcp_list_into_str(local_fcp_list)
+
+    fcp_section = list()
+    fcp_str = ''
+    if fcp_list:
+        # sort fcp_list in hex order, e.g.
+        # before sort: ['1E01', '1A02', '1D03']
+        # after sort:  ['1A02', '1D03', '1E01']
+        fcp_list.sort()
+        __transform_fcp_list_into_str(fcp_list)
+        # return a string contains all FCP
+        fcp_str = ', '.join(fcp_section).upper()
+    return fcp_str
+
+
+def verify_fcp_list_in_hex_format(fcp_list):
+    """Verify each FCP in the list is in Hex format
+    :param fcp_list: (list) a list object contains FCPs.
+    """
+    if not isinstance(fcp_list, list):
+        errmsg = ('fcp_list ({}) is not a list object.'
+                  '').format(fcp_list)
+        raise exception.SDKInvalidInputFormat(msg=errmsg)
+    # Verify each FCP should be a 4-digit hex
+    for fcp in fcp_list:
+        if not (len(fcp) == 4 and
+                all(char in string.hexdigits for char in fcp)):
+            errmsg = ('FCP list {} contains non-hex value.'
+                      '').format(fcp_list)
+            raise exception.SDKInvalidInputFormat(msg=errmsg)
